@@ -67,7 +67,7 @@ chkcolor <- function(x, length = 0, name = NULL, single = FALSE) {
     stop("Argument '", name, "' must be a character or numeric vector.",
          call. = FALSE)
 }
-chklength <- function(x, k.all, fun, text, name = NULL) {
+chklength <- function(x, k.all, fun = "", text, name = NULL) {
   ##
   ## Check length of vector
   ##
@@ -183,7 +183,7 @@ chknumeric <- function(x, min, max, zero = FALSE, length = 0,
   ##
   x <- x[!is.na(x)]
   if (length(x) == 0)
-    return(invisible(NULL))
+    return(NULL)
   ##
   if (!is.numeric(x))
     stop("Non-numeric value for argument '", name, "'.",
