@@ -1,8 +1,9 @@
 #' Meta-analysis of correlations
 #' 
 #' @description
-#' Calculation of fixed and random effects estimates for meta-analyses
-#' with correlations; inverse variance weighting is used for pooling.
+#' Calculation of fixed effect / common effect and random effects
+#' estimates for meta-analyses with correlations; inverse variance
+#' weighting is used for pooling.
 #' 
 #' @param cor Correlation.
 #' @param n Number of observations.
@@ -19,11 +20,11 @@
 #'   studies.
 #' @param level The level used to calculate confidence intervals for
 #'   individual studies.
-#' @param level.comb The level used to calculate confidence intervals
-#'   for pooled estimates.
-#' @param comb.fixed A logical indicating whether a fixed effect
-#'   meta-analysis should be conducted.
-#' @param comb.random A logical indicating whether a random effects
+#' @param level.ma The level used to calculate confidence intervals
+#'   for meta-analysis estimates.
+#' @param fixed A logical indicating whether a fixed effect / common
+#'   effect meta-analysis should be conducted.
+#' @param random A logical indicating whether a random effects
 #'   meta-analysis should be conducted.
 #' @param overall A logical indicating whether overall summaries
 #'   should be reported. This argument is useful in a meta-analysis
@@ -82,21 +83,26 @@
 #' @param title Title of meta-analysis / systematic review.
 #' @param complab Comparison label.
 #' @param outclab Outcome label.
-#' @param byvar An optional vector containing grouping information
-#'   (must be of same length as \code{event.e}).
-#' @param bylab A character string with a label for the grouping
-#'   variable.
-#' @param print.byvar A logical indicating whether the name of the
-#'   grouping variable should be printed in front of the group labels.
-#' @param byseparator A character string defining the separator
-#'   between label and levels of grouping variable.
+#' @param subgroup An optional vector to conduct a meta-analysis with
+#'   subgroups.
+#' @param subgroup.name A character string with a name for the
+#'   subgroup variable.
+#' @param print.subgroup.name A logical indicating whether the name of
+#'   the subgroup variable should be printed in front of the group
+#'   labels.
+#' @param sep.subgroup A character string defining the separator
+#'   between name of subgroup variable and subgroup label.
 #' @param test.subgroup A logical value indicating whether to print
 #'   results of test for subgroup differences.
+#' @param byvar Deprecated argument (replaced by 'subgroup').
 #' @param keepdata A logical indicating whether original data (set)
 #'   should be kept in meta object.
+#' @param warn.deprecated A logical indicating whether warnings should
+#'   be printed if deprecated arguments are used.
 #' @param control An optional list to control the iterative process to
 #'   estimate the between-study variance \eqn{\tau^2}. This argument
 #'   is passed on to \code{\link[metafor]{rma.uni}}.
+#' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
 #' Fixed effect and random effects meta-analysis of correlations based
@@ -196,7 +202,7 @@
 #' 
 #' A prediction interval for the proportion in a new study (Higgins et
 #' al., 2009) is calculated if arguments \code{prediction} and
-#' \code{comb.random} are \code{TRUE}. Note, the definition of
+#' \code{random} are \code{TRUE}. Note, the definition of
 #' prediction intervals varies in the literature. This function
 #' implements equation (12) of Higgins et al., (2009) which proposed a
 #' \emph{t} distribution with \emph{K-2} degrees of freedom where
@@ -205,7 +211,7 @@
 #'
 #' \subsection{Subgroup analysis}{
 #' 
-#' Argument \code{byvar} can be used to conduct subgroup analysis for
+#' Argument \code{subgroup} can be used to conduct subgroup analysis for
 #' a categorical covariate. The \code{\link{metareg}} function can be
 #' used instead for more than one categorical covariate or continuous
 #' covariates.
@@ -225,14 +231,14 @@
 #' 
 #' Internally, both fixed effect and random effects models are
 #' calculated regardless of values choosen for arguments
-#' \code{comb.fixed} and \code{comb.random}. Accordingly, the estimate
+#' \code{fixed} and \code{random}. Accordingly, the estimate
 #' for the random effects model can be extracted from component
 #' \code{TE.random} of an object of class \code{"meta"} even if
-#' argument \code{comb.random = FALSE}. However, all functions in R
+#' argument \code{random = FALSE}. However, all functions in R
 #' package \bold{meta} will adequately consider the values for
-#' \code{comb.fixed} and \code{comb.random}. E.g. functions
+#' \code{fixed} and \code{random}. E.g. functions
 #' \code{\link{print.meta}} and \code{\link{forest.meta}} will not
-#' print results for the random effects model if \code{comb.random =
+#' print results for the random effects model if \code{random =
 #' FALSE}.
 #' }
 #' 
@@ -246,13 +252,13 @@
 #' \code{print}, \code{summary}, and \code{forest} functions. The
 #' object is a list containing the following components:
 #' \item{cor, n, studlab, exclude,}{As defined above.}
-#' \item{sm, level, level.comb,}{As defined above.}
-#' \item{comb.fixed, comb.random,}{As defined above.}
+#' \item{sm, level, level.ma,}{As defined above.}
+#' \item{fixed, random,}{As defined above.}
 #' \item{hakn, adhoc.hakn, method.tau, method.tau.ci,}{As defined above.}
 #' \item{tau.preset, TE.tau, method.bias,}{As defined above.}
 #' \item{method.bias, tau.common, title, complab, outclab,}{As defined
 #'   above.}
-#' \item{byvar, bylab, print.byvar, byseparator}{As defined above.}
+#' \item{subgroup, subgroup.name, print.subgroup.name, sep.subgroup}{As defined above.}
 #' \item{TE, seTE}{Either Fisher's z transformation of correlations
 #'   (\code{sm = "ZCOR"}) or correlations (\code{sm="COR"}) for
 #'   individual studies.}
@@ -305,77 +311,77 @@
 #' \item{df.hakn}{Degrees of freedom for test of effect for
 #'   Hartung-Knapp method (only if \code{hakn = TRUE}).}
 #' \item{method}{Pooling method: \code{"Inverse"}.}
-#' \item{bylevs}{Levels of grouping variable - if \code{byvar} is not
+#' \item{bylevs}{Levels of grouping variable - if \code{subgroup} is not
 #'   missing.}
 #' \item{TE.fixed.w, seTE.fixed.w}{Estimated effect and
 #'   standard error in subgroups (fixed effect model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.fixed.w, upper.fixed.w}{Lower and upper confidence
 #'   interval limits in subgroups (fixed effect model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{statistic.fixed.w, pval.fixed.w}{z-value and p-value for test
-#'   of effect in subgroups (fixed effect model) - if \code{byvar} is
+#'   of effect in subgroups (fixed effect model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{TE.random.w, seTE.random.w}{Estimated effect and standard
-#'   error in subgroups (random effects model) - if \code{byvar} is
+#'   error in subgroups (random effects model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{lower.random.w, upper.random.w}{Lower and upper confidence
 #'   interval limits in subgroups (random effects model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{statistic.random.w, pval.random.w}{z-value or t-value and
 #'   corresponding p-value for test of effect in subgroups (random
-#'   effects model) - if \code{byvar} is not missing.}
+#'   effects model) - if \code{subgroup} is not missing.}
 #' \item{w.fixed.w, w.random.w}{Weight of subgroups (in fixed and
-#'   random effects model) - if \code{byvar} is not missing.}
+#'   random effects model) - if \code{subgroup} is not missing.}
 #' \item{df.hakn.w}{Degrees of freedom for test of effect for
-#'   Hartung-Knapp method in subgroups - if \code{byvar} is not
+#'   Hartung-Knapp method in subgroups - if \code{subgroup} is not
 #'   missing and \code{hakn = TRUE}.}
 #' \item{n.e.w}{Number of observations in experimental group in
-#'   subgroups - if \code{byvar} is not missing.}
+#'   subgroups - if \code{subgroup} is not missing.}
 #' \item{n.c.w}{Number of observations in control group in subgroups -
-#'   if \code{byvar} is not missing.}
+#'   if \code{subgroup} is not missing.}
 #' \item{k.w}{Number of studies combined within subgroups - if
-#'   \code{byvar} is not missing.}
-#' \item{k.all.w}{Number of all studies in subgroups - if \code{byvar}
+#'   \code{subgroup} is not missing.}
+#' \item{k.all.w}{Number of all studies in subgroups - if \code{subgroup}
 #'   is not missing.}
 #' \item{Q.w.fixed}{Overall within subgroups heterogeneity statistic Q
-#'   (based on fixed effect model) - if \code{byvar} is not missing.}
+#'   (based on fixed effect model) - if \code{subgroup} is not missing.}
 #' \item{Q.w.random}{Overall within subgroups heterogeneity statistic
-#'   Q (based on random effects model) - if \code{byvar} is not
+#'   Q (based on random effects model) - if \code{subgroup} is not
 #'   missing (only calculated if argument \code{tau.common} is TRUE).}
 #' \item{df.Q.w}{Degrees of freedom for test of overall within
-#'   subgroups heterogeneity - if \code{byvar} is not missing.}
+#'   subgroups heterogeneity - if \code{subgroup} is not missing.}
 #' \item{pval.Q.w.fixed}{P-value of within subgroups heterogeneity
-#'   statistic Q (based on fixed effect model) - if \code{byvar} is
+#'   statistic Q (based on fixed effect model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{pval.Q.w.random}{P-value of within subgroups heterogeneity
-#'   statistic Q (based on random effects model) - if \code{byvar} is
+#'   statistic Q (based on random effects model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{Q.b.fixed}{Overall between subgroups heterogeneity statistic
-#'   Q (based on fixed effect model) - if \code{byvar} is not
+#'   Q (based on fixed effect model) - if \code{subgroup} is not
 #'   missing.}
 #' \item{Q.b.random}{Overall between subgroups heterogeneity statistic
-#'   Q (based on random effects model) - if \code{byvar} is not
+#'   Q (based on random effects model) - if \code{subgroup} is not
 #'   missing.}
 #' \item{df.Q.b}{Degrees of freedom for test of overall between
-#'   subgroups heterogeneity - if \code{byvar} is not missing.}
+#'   subgroups heterogeneity - if \code{subgroup} is not missing.}
 #' \item{pval.Q.b.fixed}{P-value of between subgroups heterogeneity
-#'   statistic Q (based on fixed effect model) - if \code{byvar} is
+#'   statistic Q (based on fixed effect model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{pval.Q.b.random}{P-value of between subgroups heterogeneity
-#'   statistic Q (based on random effects model) - if \code{byvar} is
+#'   statistic Q (based on random effects model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{tau.w}{Square-root of between-study variance within subgroups
-#'   - if \code{byvar} is not missing.}
+#'   - if \code{subgroup} is not missing.}
 #' \item{H.w}{Heterogeneity statistic H within subgroups - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.H.w, upper.H.w}{Lower and upper confidence limit for
-#'   heterogeneity statistic H within subgroups - if \code{byvar} is
+#'   heterogeneity statistic H within subgroups - if \code{subgroup} is
 #'   not missing.}
 #' \item{I2.w}{Heterogeneity statistic I\eqn{^2} within subgroups - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.I2.w, upper.I2.w}{Lower and upper confidence limit for
-#'   heterogeneity statistic I\eqn{^2} within subgroups - if \code{byvar} is
+#'   heterogeneity statistic I\eqn{^2} within subgroups - if \code{subgroup} is
 #'   not missing.}
 #' \item{keepdata}{As defined above.}
 #' \item{data}{Original data (set) used in function call (if
@@ -491,11 +497,11 @@ metacor <- function(cor, n, studlab,
                     ##
                     sm = gs("smcor"),
                     ##
-                    level = gs("level"), level.comb = gs("level.comb"),
-                    comb.fixed = gs("comb.fixed"),
-                    comb.random = gs("comb.random"),
-                    overall = comb.fixed | comb.random,
-                    overall.hetstat = comb.fixed | comb.random,
+                    level = gs("level"), level.ma = gs("level.ma"),
+                    fixed = gs("fixed"),
+                    random = gs("random") | !is.null(tau.preset),
+                    overall = fixed | random,
+                    overall.hetstat = fixed | random,
                     ##
                     hakn = gs("hakn"), adhoc.hakn = gs("adhoc.hakn"),
                     method.tau = gs("method.tau"),
@@ -521,14 +527,17 @@ metacor <- function(cor, n, studlab,
                     title = gs("title"), complab = gs("complab"),
                     outclab = "",
                     ##
-                    byvar, bylab, print.byvar = gs("print.byvar"),
-                    byseparator = gs("byseparator"),
+                    subgroup, subgroup.name = NULL,
+                    print.subgroup.name = gs("print.subgroup.name"),
+                    sep.subgroup = gs("sep.subgroup"),
                     test.subgroup = gs("test.subgroup"),
+                    byvar,
                     ##
                     keepdata = gs("keepdata"),
+                    warn.deprecated = gs("warn.deprecated"),
                     ##
-                    control = NULL
-                    ) {
+                    control = NULL,
+                    ...) {
   
   
   ##
@@ -538,11 +547,6 @@ metacor <- function(cor, n, studlab,
   ##
   chknull(sm)
   chklevel(level)
-  chklevel(level.comb)
-  chklogical(comb.fixed)
-  chklogical(comb.random)
-  chklogical(overall)
-  chklogical(overall.hetstat)
   ##
   chklogical(hakn)
   adhoc.hakn <- setchar(adhoc.hakn, .settings$adhoc4hakn)
@@ -574,6 +578,45 @@ metacor <- function(cor, n, studlab,
   ##
   chklogical(keepdata)
   ##
+  ## Check for deprecated arguments in '...'
+  ##
+  args  <- list(...)
+  chklogical(warn.deprecated)
+  ##
+  level.ma <- deprecated(level.ma, missing(level.ma), args, "level.comb",
+                         warn.deprecated)
+  chklevel(level.ma)
+  ##
+  fixed <- deprecated(fixed, missing(fixed), args, "comb.fixed",
+                      warn.deprecated)
+  chklogical(fixed)
+  ##
+  random <- deprecated(random, missing(random), args, "comb.random",
+                       warn.deprecated)
+  chklogical(random)
+  ##
+  missing.subgroup.name <- missing(subgroup.name)
+  subgroup.name <-
+    deprecated(subgroup.name, missing.subgroup.name, args, "bylab",
+               warn.deprecated)
+  ##
+  print.subgroup.name <-
+    deprecated(print.subgroup.name, missing(print.subgroup.name),
+               args, "print.byvar", warn.deprecated)
+  print.subgroup.name <- replaceNULL(print.subgroup.name, FALSE)
+  chklogical(print.subgroup.name)
+  ##
+  sep.subgroup <-
+    deprecated(sep.subgroup, missing(sep.subgroup), args, "byseparator",
+               warn.deprecated)
+  if (!is.null(sep.subgroup))
+    chkchar(sep.subgroup, length = 1)
+  ##
+  ## Some more checks
+  ##
+  chklogical(overall)
+  chklogical(overall.hetstat)
+  ##
   ## Additional arguments / checks for metacor objects
   ##
   fun <- "metacor"
@@ -603,15 +646,20 @@ metacor <- function(cor, n, studlab,
             data, enclos = sys.frame(sys.parent()))
   chknull(n)
   ##
-  ## Catch 'studlab', 'byvar', 'subset' and 'exclude' from data:
+  ## Catch 'studlab', 'subgroup', 'subset' and 'exclude' from data:
   ##
   studlab <- eval(mf[[match("studlab", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
   studlab <- setstudlab(studlab, k.All)
   ##
+  missing.subgroup <- missing(subgroup)
+  subgroup <- eval(mf[[match("subgroup", names(mf))]],
+                   data, enclos = sys.frame(sys.parent()))
+  missing.byvar <- missing(byvar)
   byvar <- eval(mf[[match("byvar", names(mf))]],
                 data, enclos = sys.frame(sys.parent()))
-  by <- !is.null(byvar)
+  subgroup <- deprecated2(subgroup, missing.subgroup, byvar, missing.byvar)
+  by <- !is.null(subgroup)
   ##
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
@@ -620,6 +668,19 @@ metacor <- function(cor, n, studlab,
   exclude <- eval(mf[[match("exclude", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
   missing.exclude <- is.null(exclude)
+  ##
+  ## Additional checks
+  ##
+  if (!by & tau.common) {
+    warning("Value for argument 'tau.common' set to FALSE as ",
+            "argument 'subgroup' is missing.")
+    tau.common <- FALSE
+  }
+  if (by & !tau.common & !is.null(tau.preset)) {
+    warning("Argument 'tau.common' set to TRUE as ",
+            "argument tau.preset is not NULL.")
+    tau.common <- TRUE
+  }
   
   
   ##
@@ -631,20 +692,9 @@ metacor <- function(cor, n, studlab,
   chklength(studlab, k.All, fun)
   ##
   if (by) {
-    chklength(byvar, k.All, fun)
+    chklength(subgroup, k.All, fun)
     chklogical(test.subgroup)
   }
-  ##
-  ## Additional checks
-  ##
-  if (!by & tau.common) {
-    warning("Value for argument 'tau.common' set to FALSE as argument 'byvar' is missing.")
-    tau.common <- FALSE
-  }
-  if (by & !tau.common & !is.null(tau.preset)) {
-    warning("Argument 'tau.common' set to TRUE as argument tau.preset is not NULL.")
-    tau.common <- TRUE
-  }
   
   
   ##
@@ -686,7 +736,7 @@ metacor <- function(cor, n, studlab,
     data$.studlab <- studlab
     ##
     if (by)
-      data$.byvar <- byvar
+      data$.subgroup <- subgroup
     ##
     if (!missing.subset) {
       if (length(subset) == dim(data)[1])
@@ -715,7 +765,7 @@ metacor <- function(cor, n, studlab,
     exclude <- exclude[subset]
     ##
     if (by)
-      byvar <- byvar[subset]
+      subgroup <- subgroup[subset]
   }
   ##
   ## Determine total number of studies
@@ -728,8 +778,8 @@ metacor <- function(cor, n, studlab,
   ## No meta-analysis for a single study
   ##
   if (k.all == 1) {
-    comb.fixed <- FALSE
-    comb.random <- FALSE
+    fixed <- FALSE
+    random <- FALSE
     prediction <- FALSE
     overall <- FALSE
     overall.hetstat <- FALSE
@@ -741,10 +791,18 @@ metacor <- function(cor, n, studlab,
   chknumeric(n, 0, zero = TRUE)
   ##
   if (by) {
-    chkmiss(byvar)
-    byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
-    bylab <- if (!missing(bylab) && !is.null(bylab)) bylab else byvar.name
+    chkmiss(subgroup)
+    ##
+    if (missing.subgroup.name & is.null(subgroup.name)) {
+      if (!missing.subgroup)
+        subgroup.name <- byvarname(mf[[match("subgroup", names(mf))]])
+      else if (!missing.byvar)
+        subgroup.name <- byvarname(mf[[match("byvar", names(mf))]])
+    }
   }
+  ##
+  if (!is.null(subgroup.name))
+    chkchar(subgroup.name, length = 1)
   
   
   ##
@@ -774,9 +832,9 @@ metacor <- function(cor, n, studlab,
                ##
                sm = sm,
                level = level,
-               level.comb = level.comb,
-               comb.fixed = comb.fixed,
-               comb.random = comb.random,
+               level.ma = level.ma,
+               fixed = fixed,
+               random = random,
                overall = overall,
                overall.hetstat = overall.hetstat,
                ##
@@ -809,7 +867,7 @@ metacor <- function(cor, n, studlab,
   if (by & tau.common) {
     ## Estimate common tau-squared across subgroups
     hcc <- hetcalc(TE, seTE, method.tau, "",
-                   TE.tau, level.comb, byvar, control)
+                   TE.tau, level.ma, subgroup, control)
   }
   
   
@@ -849,10 +907,10 @@ metacor <- function(cor, n, studlab,
   ## Add results from subgroup analysis
   ##
   if (by) {
-    res$byvar <- byvar
-    res$bylab <- bylab
-    res$print.byvar <- print.byvar
-    res$byseparator <- byseparator
+    res$subgroup <- subgroup
+    res$subgroup.name <- subgroup.name
+    res$print.subgroup.name <- print.subgroup.name
+    res$sep.subgroup <- sep.subgroup
     res$test.subgroup <- test.subgroup
     res$tau.common <- tau.common
     ##
@@ -908,6 +966,19 @@ metacor <- function(cor, n, studlab,
     res$time.c.w <- NULL
   }
   ##
+  ## Backward compatibility
+  ##
+  res$comb.fixed <- fixed
+  res$comb.random <- random
+  res$level.comb <- level.ma
+  ##
+  if (by) {
+    res$byvar <- subgroup
+    res$bylab <- subgroup.name
+    res$print.byvar <- print.subgroup.name
+    res$byseparator <- sep.subgroup
+  }
+  ##
   class(res) <- c(fun, "meta")
   
   
